@@ -12,7 +12,7 @@ do
 done
 
 cat <<EOF | kubectl apply --validate=false -f -
-apiVersion: rbac.authorization.k8s.io/v1beta1
+apiVersion: rbac.authorization.k8s.io/v1
 kind: ClusterRole
 metadata:
   annotations:
@@ -34,7 +34,7 @@ rules:
 EOF
 
 cat <<EOF | kubectl apply --validate=false -f -
-apiVersion: rbac.authorization.k8s.io/v1beta1
+apiVersion: rbac.authorization.k8s.io/v1
 kind: ClusterRoleBinding
 metadata:
   name: system:kube-apiserver
@@ -62,7 +62,7 @@ metadata:
   name: admin
   namespace: kube-system
 ---
-apiVersion: rbac.authorization.k8s.io/v1beta1
+apiVersion: rbac.authorization.k8s.io/v1
 kind: ClusterRoleBinding
 metadata:
   name: admin
@@ -78,67 +78,6 @@ EOF
 }
 kubectl apply --validate=false -f ${ADMIN_RBAC}
 
-POD_SECURITY_POLICIES=/srv/magnum/kubernetes/podsecuritypolicies.yaml
-# Pod Security Policies
-[ -f ${POD_SECURITY_POLICIES} ] || {
-    echo "Writing File: $POD_SECURITY_POLICIES"
-    mkdir -p $(dirname ${POD_SECURITY_POLICIES})
-    cat > ${POD_SECURITY_POLICIES} <<EOF
----
-apiVersion: policy/v1beta1
-kind: PodSecurityPolicy
-metadata:
-  name: magnum.privileged
-  annotations:
-    kubernetes.io/description: 'privileged allows full unrestricted access to
-      pod features, as if the PodSecurityPolicy controller was not enabled.'
-    seccomp.security.alpha.kubernetes.io/allowedProfileNames: '*'
-  labels:
-    kubernetes.io/cluster-service: "true"
-    addonmanager.kubernetes.io/mode: Reconcile
-spec:
-  privileged: true
-  allowPrivilegeEscalation: true
-  allowedCapabilities:
-  - '*'
-  volumes:
-  - '*'
-  hostNetwork: true
-  hostPorts:
-  - min: 0
-    max: 65535
-  hostIPC: true
-  hostPID: true
-  runAsUser:
-    rule: 'RunAsAny'
-  seLinux:
-    rule: 'RunAsAny'
-  supplementalGroups:
-    rule: 'RunAsAny'
-  fsGroup:
-    rule: 'RunAsAny'
-  readOnlyRootFilesystem: false
----
-apiVersion: rbac.authorization.k8s.io/v1
-kind: ClusterRole
-metadata:
-  name: magnum:podsecuritypolicy:privileged
-  labels:
-    kubernetes.io/cluster-service: "true"
-    addonmanager.kubernetes.io/mode: Reconcile
-rules:
-- apiGroups:
-  - policy
-  resourceNames:
-  - magnum.privileged
-  resources:
-  - podsecuritypolicies
-  verbs:
-  - use
-EOF
-}
-kubectl apply -f ${POD_SECURITY_POLICIES}
-
 # Add the openstack trustee as a secret under kube-system
 kubectl -n kube-system create secret generic os-trustee \
     --from-literal=os-authURL=${AUTH_URL} \
@@ -370,6 +309,9 @@ spec:
         - --cluster-name=${CLUSTER_UUID}
         - --use-service-account-credentials=true
         - --bind-address=127.0.0.1
+        resources:
+          requests:
+            cpu: 200m
         volumeMounts:
         - name: cloudconfig
           mountPath: /etc/kubernetes
