@@ -18,7 +18,6 @@ Tests for `magnum` module.
 """
 
 import os
-from oslo_config import cfg
 import subprocess
 import tempfile
 import time
@@ -27,17 +26,23 @@ import fixtures
 from six.moves import configparser
 
 from heatclient import client as heatclient
-from k8sclient.client import api_client
-from k8sclient.client.apis import apiv_api
-from keystoneclient.v2_0 import client as ksclient
+from keystoneauth1.identity import v3 as ksa_v3
+from keystoneauth1 import session as ksa_session
+from keystoneclient.v3 import client as ksclient
+from kubernetes import client as k8s_config
+from kubernetes.client import api_client
+from kubernetes.client.apis import core_v1_api
+
 from magnum.common.utils import rmtree_without_raise
-from magnum.i18n import _LI
+import magnum.conf
 from magnum.tests.functional.common import base
 from magnum.tests.functional.common import utils
 from magnumclient.common.apiclient import exceptions
 from magnumclient.common import cliutils
 from magnumclient.v1 import client as v1client
 
+CONF = magnum.conf.CONF
+
 
 class BaseMagnumClient(base.BaseMagnumTest):
 
@@ -50,9 +55,9 @@ class BaseMagnumClient(base.BaseMagnumTest):
         super(BaseMagnumClient, cls).setUpClass()
         user = cliutils.env('OS_USERNAME')
         passwd = cliutils.env('OS_PASSWORD')
-        tenant = cliutils.env('OS_TENANT_NAME')
-        tenant_id = cliutils.env('OS_TENANT_ID')
+        project_name = cliutils.env('OS_PROJECT_NAME')
         auth_url = cliutils.env('OS_AUTH_URL')
+        insecure = cliutils.env('INSECURE')
         region_name = cliutils.env('OS_REGION_NAME')
         magnum_url = cliutils.env('BYPASS_URL')
         image_id = cliutils.env('IMAGE_ID')
@@ -62,6 +67,8 @@ class BaseMagnumClient(base.BaseMagnumTest):
         keypair_id = cliutils.env('KEYPAIR_ID')
         dns_nameserver = cliutils.env('DNS_NAMESERVER')
         copy_logs = cliutils.env('COPY_LOGS')
+        user_domain_id = cliutils.env('OS_USER_DOMAIN_ID')
+        project_domain_id = cliutils.env('OS_PROJECT_DOMAIN_ID')
 
         config = configparser.RawConfigParser()
         if config.read('functional_creds.conf'):
@@ -69,8 +76,9 @@ class BaseMagnumClient(base.BaseMagnumTest):
             # override
             user = user or config.get('admin', 'user')
             passwd = passwd or config.get('admin', 'pass')
-            tenant = tenant or config.get('admin', 'tenant')
+            project_name = project_name or config.get('admin', 'project_name')
             auth_url = auth_url or config.get('auth', 'auth_url')
+            insecure = insecure or config.get('auth', 'insecure')
             magnum_url = magnum_url or config.get('auth', 'magnum_url')
             image_id = image_id or config.get('magnum', 'image_id')
             nic_id = nic_id or config.get('magnum', 'nic_id')
@@ -80,6 +88,11 @@ class BaseMagnumClient(base.BaseMagnumTest):
             keypair_id = keypair_id or config.get('magnum', 'keypair_id')
             dns_nameserver = dns_nameserver or config.get(
                 'magnum', 'dns_nameserver')
+            user_domain_id = user_domain_id or config.get(
+                'admin', 'user_domain_id')
+            project_domain_id = project_domain_id or config.get(
+                'admin', 'project_domain_id')
+
             try:
                 copy_logs = copy_logs or config.get('magnum', 'copy_logs')
             except configparser.NoOptionError:
@@ -92,22 +105,57 @@ class BaseMagnumClient(base.BaseMagnumTest):
         cls.keypair_id = keypair_id
         cls.dns_nameserver = dns_nameserver
         cls.copy_logs = str(copy_logs).lower() == 'true'
-        cls.cs = v1client.Client(username=user,
-                                 api_key=passwd,
-                                 project_id=tenant_id,
-                                 project_name=tenant,
-                                 auth_url=auth_url,
+
+        # NOTE(clenimar): The recommended way to issue clients is by creating
+        # a keystoneauth Session. Using auth parameters (e.g. username and
+        # password) directly is deprecated.
+        _session = cls._get_auth_session(username=user,
+                                         password=passwd,
+                                         project_name=project_name,
+                                         project_domain_id=project_domain_id,
+                                         user_domain_id=user_domain_id,
+                                         auth_url=auth_url,
+                                         insecure=insecure)
+
+        cls.cs = v1client.Client(session=_session,
+                                 insecure=insecure,
                                  service_type='container-infra',
                                  region_name=region_name,
-                                 magnum_url=magnum_url)
-        cls.keystone = ksclient.Client(username=user,
-                                       password=passwd,
-                                       tenant_name=tenant,
-                                       auth_url=auth_url)
-        token = cls.keystone.auth_token
-        heat_endpoint = cls.keystone.service_catalog.url_for(
+                                 magnum_url=magnum_url,
+                                 api_version='latest')
+
+        cls.keystone = ksclient.Client(session=_session)
+
+        # Get heat endpoint from session
+        auth_ref = _session.auth.get_auth_ref(_session)
+        heat_endpoint = auth_ref.service_catalog.url_for(
             service_type='orchestration')
-        cls.heat = heatclient.Client('1', token=token, endpoint=heat_endpoint)
+
+        cls.heat = heatclient.Client('1', session=_session,
+                                     auth=_session.auth,
+                                     endpoint=heat_endpoint)
+
+    @classmethod
+    def _get_auth_session(cls, username, password, project_name,
+                          project_domain_id, user_domain_id, auth_url,
+                          insecure):
+        """Return a `keystoneauth1.session.Session` from auth parameters."""
+        # create v3Password auth plugin
+        _auth = ksa_v3.Password(username=username,
+                                password=password,
+                                project_name=project_name,
+                                project_domain_id=project_domain_id,
+                                user_domain_id=user_domain_id,
+                                auth_url=auth_url)
+
+        # `insecure` is being replaced by `verify`. Please note they have
+        # opposite meanings.
+        verify = False if insecure else True
+
+        # create a `keystoneauth1.session.Session`
+        _session = ksa_session.Session(auth=_auth, verify=verify)
+
+        return _session
 
     @classmethod
     def _wait_on_status(cls, cluster, wait_status, finish_status,
@@ -116,7 +164,7 @@ class BaseMagnumClient(base.BaseMagnumTest):
 
         def _check_status():
             status = cls.cs.clusters.get(cluster.uuid).status
-            cls.LOG.debug("Cluster status is %s" % status)
+            cls.LOG.debug("Cluster status is %s", status)
             if status in wait_status:
                 return False
             elif status in finish_status:
@@ -136,7 +184,6 @@ class BaseMagnumClient(base.BaseMagnumTest):
         #                Plan is to support other kinds of ClusterTemplate
         #                creation.
         coe = kwargs.pop('coe', 'kubernetes')
-        docker_volume_size = kwargs.pop('docker_volume_size', 3)
         network_driver = kwargs.pop('network_driver', 'flannel')
         volume_driver = kwargs.pop('volume_driver', 'cinder')
         labels = kwargs.pop('labels', {"K1": "V1", "K2": "V2"})
@@ -151,7 +198,6 @@ class BaseMagnumClient(base.BaseMagnumTest):
             image_id=cls.image_id,
             flavor_id=cls.flavor_id,
             master_flavor_id=cls.master_flavor_id,
-            docker_volume_size=docker_volume_size,
             network_driver=network_driver,
             volume_driver=volume_driver,
             dns_nameserver=cls.dns_nameserver,
@@ -195,7 +241,7 @@ class BaseMagnumClient(base.BaseMagnumTest):
         except exceptions.NotFound:
             pass
         else:
-            if cls._show_cluster(cls.clustser.uuid).status == 'DELETE_FAILED':
+            if cls._show_cluster(cls.cluster.uuid).status == 'DELETE_FAILED':
                 raise Exception("Cluster %s delete failed" % cls.cluster.uuid)
 
     @classmethod
@@ -211,7 +257,7 @@ class BaseMagnumClient(base.BaseMagnumTest):
         )
 
         if self.cs.clusters.get(cluster.uuid).status == 'CREATE_FAILED':
-            raise Exception("Cluster %s created failed" % cluster.uuid)
+            raise Exception("Cluster %s create failed" % cluster.uuid)
 
         return cluster
 
@@ -226,7 +272,12 @@ distinguished_name = req_distinguished_name
 req_extensions     = req_ext
 prompt = no
 [req_distinguished_name]
-CN = Your Name
+CN = admin
+O = system:masters
+OU=OpenStack/Magnum
+C=US
+ST=TX
+L=Austin
 [req_ext]
 extendedKeyUsage = clientAuth
 """
@@ -248,6 +299,24 @@ extendedKeyUsage = clientAuth
         cls.cluster = cls._create_cluster(cls.__name__,
                                           cls.cluster_template.uuid)
         if not cls.cluster_template_kwargs.get('tls_disabled', False):
+            # NOTE (wangbo) with multiple mangum-conductor processes, client
+            # ca files should be created after completion of cluster ca_cert
+            try:
+                cls._wait_on_status(
+                    cls.cluster,
+                    [None, "CREATE_IN_PROGRESS"],
+                    ["CREATE_FAILED", "CREATE_COMPLETE"],
+                    timeout=cls.cluster_complete_timeout
+                )
+            except Exception:
+                # copy logs if setUpClass fails, may be this will not work
+                # as master_address, node_address would not be available, if
+                # not we can get that from nova
+                if cls.copy_logs:
+                    cls.copy_logs_handler(
+                        cls._get_nodes,
+                        cls.cluster_template.coe,
+                        'default')
             cls._create_tls_ca_files(cls.config_contents)
 
     @classmethod
@@ -268,14 +337,15 @@ extendedKeyUsage = clientAuth
             test_timeout = int(test_timeout)
         except ValueError:
             # If timeout value is invalid, set a default timeout.
-            test_timeout = cfg.CONF.cluster_heat.create_timeout
+            test_timeout = CONF.cluster_heat.create_timeout
         if test_timeout <= 0:
-            test_timeout = cfg.CONF.cluster_heat.create_timeout
+            test_timeout = CONF.cluster_heat.create_timeout
 
         self.useFixture(fixtures.Timeout(test_timeout, gentle=True))
 
+        # Copy cluster nodes logs
         if self.copy_logs:
-            self.addOnException(
+            self.addCleanup(
                 self.copy_logs_handler(
                     self._get_nodes,
                     self.cluster_template.coe,
@@ -285,11 +355,11 @@ extendedKeyUsage = clientAuth
     def _get_nodes(self):
         nodes = self._get_nodes_from_cluster()
         if not [x for x in nodes if x]:
-            self.LOG.info(_LI("the list of nodes from cluster is empty"))
+            self.LOG.info("the list of nodes from cluster is empty")
             nodes = self._get_nodes_from_stack()
             if not [x for x in nodes if x]:
-                self.LOG.info(_LI("the list of nodes from stack is empty"))
-        self.LOG.info(_LI("Nodes are: %s") % nodes)
+                self.LOG.info("the list of nodes from stack is empty")
+        self.LOG.info("Nodes are: %s", nodes)
         return nodes
 
     def _get_nodes_from_cluster(self):
@@ -299,16 +369,19 @@ extendedKeyUsage = clientAuth
         return nodes
 
     def _get_nodes_from_stack(self):
+        cluster = self.cs.clusters.get(self.cluster.uuid)
         nodes = []
-        stack = self.heat.stacks.get(self.cluster.stack_id)
+        stack = self.heat.stacks.get(cluster.stack_id)
         stack_outputs = stack.to_dict().get('outputs', [])
         output_keys = []
         if self.cluster_template.coe == "kubernetes":
             output_keys = ["kube_masters", "kube_minions"]
         elif self.cluster_template.coe == "swarm":
             output_keys = ["swarm_masters", "swarm_nodes"]
-        elif self.cluster_template.coe == "mesos":
-            output_keys = ["mesos_master", "mesos_slaves"]
+        elif self.cluster_template.coe == "swarm-mode":
+            output_keys = ["swarm_primary_master",
+                           "swarm_secondary_masters",
+                           "swarm_nodes"]
 
         for output in stack_outputs:
             for key in output_keys:
@@ -371,30 +444,34 @@ class BaseK8sTest(ClusterTest):
     def setUpClass(cls):
         super(BaseK8sTest, cls).setUpClass()
         cls.kube_api_url = cls.cs.clusters.get(cls.cluster.uuid).api_address
-        k8s_client = api_client.ApiClient(cls.kube_api_url,
-                                          key_file=cls.key_file,
-                                          cert_file=cls.cert_file,
-                                          ca_certs=cls.ca_file)
-        cls.k8s_api = apiv_api.ApivApi(k8s_client)
+        config = k8s_config.Configuration()
+        config.host = cls.kube_api_url
+        config.ssl_ca_cert = cls.ca_file
+        config.cert_file = cls.cert_file
+        config.key_file = cls.key_file
+        k8s_client = api_client.ApiClient(configuration=config)
+        cls.k8s_api = core_v1_api.CoreV1Api(k8s_client)
 
     def setUp(self):
         super(BaseK8sTest, self).setUp()
         self.kube_api_url = self.cs.clusters.get(self.cluster.uuid).api_address
-        k8s_client = api_client.ApiClient(self.kube_api_url,
-                                          key_file=self.key_file,
-                                          cert_file=self.cert_file,
-                                          ca_certs=self.ca_file)
-        self.k8s_api = apiv_api.ApivApi(k8s_client)
+        config = k8s_config.Configuration()
+        config.host = self.kube_api_url
+        config.ssl_ca_cert = self.ca_file
+        config.cert_file = self.cert_file
+        config.key_file = self.key_file
+        k8s_client = api_client.ApiClient(configuration=config)
+        self.k8s_api = core_v1_api.CoreV1Api(k8s_client)
         # TODO(coreypobrien) https://bugs.launchpad.net/magnum/+bug/1551824
         utils.wait_for_condition(self._is_api_ready, 5, 600)
 
     def _is_api_ready(self):
         try:
-            self.k8s_api.list_namespaced_node()
-            self.LOG.info(_LI("API is ready."))
+            self.k8s_api.list_node()
+            self.LOG.info("API is ready.")
             return True
         except Exception:
-            self.LOG.info(_LI("API is not ready yet."))
+            self.LOG.info("API is not ready yet.")
             return False
 
     def test_pod_apis(self):
@@ -438,7 +515,7 @@ class BaseK8sTest(ClusterTest):
         self.assertEqual('frontend', resp.metadata.name)
         self.assertTrue(resp.status)
 
-        resp = self.k8s_api.delete_namespaced_service(name='frontend',
+        resp = self.k8s_api.delete_namespaced_service(name='frontend', body={},
                                                       namespace='default')
 
     def test_replication_controller_apis(self):
